icsemantic.catalog.criteria.translation

Package platecom :: Package ontocatalog :: Package criteria :: Module translation |
[hide private]
[frames] | no frames]

# Module translation

source code

A friendly criterion for ATTopic that matches the SearchableTranslatedText index parameters.

Classes | [hide private]
| ATTranslationCriterion A translation text criterion

Variables | [hide private]
| ATTranslationCriterionSchema = `ATBaseCriterionSchema+ Schema((`...``

Variables Details | [hide private]

  ### ATTranslationCriterionSchema Value:
      ATBaseCriterionSchema+ Schema((StringField('value', required= 1, mode=
       "rw", write_permission= ChangeTopics, accessor= "Value", mutator= "se
      tValue", default= "", widget= StringWidget(label= _(u'label_translatio
      n_criterion_value', default= u'Value'), description= _(u'help_translat
      ion_criterion_value', default= u'A string value.'))), LinesField('lang
      uage', required= 1, mode= "rw", write_permission= ChangeTopics, access
      or= "Language", mutator= "setLanguage", default= [], vocabulary= "getL
      anguages", widget= MultiSelectionWidget(label= _(u'label_translation_c
      ...